summaryrefslogtreecommitdiffstats
path: root/telephony
diff options
context:
space:
mode:
authorAndroid (Google) Code Review <android-gerrit@google.com>2009-08-11 12:07:16 -0700
committerAndroid (Google) Code Review <android-gerrit@google.com>2009-08-11 12:07:16 -0700
commit7d8913336435d6184e4a5ab2e648d5e0dd76e96f (patch)
tree8c20458c77f4fe1fe850a65811fc6b9049bb4861 /telephony
parent81df0d9487ea498f9746ca33b17b5c2f5224bf72 (diff)
parentc6f79ce6bcc77abe222e5cc39a0b065bc76bce83 (diff)
downloadframeworks_base-7d8913336435d6184e4a5ab2e648d5e0dd76e96f.zip
frameworks_base-7d8913336435d6184e4a5ab2e648d5e0dd76e96f.tar.gz
frameworks_base-7d8913336435d6184e4a5ab2e648d5e0dd76e96f.tar.bz2
Merge change 20683
* changes: Add operator name in network selection.
Diffstat (limited to 'telephony')
-rw-r--r--telephony/java/com/android/internal/telephony/PhoneBase.java7
-rwxr-xr-xtelephony/java/com/android/internal/telephony/gsm/GSMPhone.java7
2 files changed, 11 insertions, 3 deletions
diff --git a/telephony/java/com/android/internal/telephony/gsm/GSMPhone.java b/telephony/java/com/android/internal/telephony/gsm/GSMPhone.java
index 6f89288..94d4344 100755
--- a/telephony/java/com/android/internal/telephony/gsm/GSMPhone.java
+++ b/telephony/java/com/android/internal/telephony/gsm/GSMPhone.java
@@ -1032,11 +1032,13 @@ public class GSMPhone extends PhoneBase {
/**
* Small container class used to hold information relevant to
* the carrier selection process. operatorNumeric can be ""
- * if we are looking for automatic selection.
+ * if we are looking for automatic selection. operatorAlphaLong is the
+ * corresponding operator name.
*/
private static class NetworkSelectMessage {
public Message message;
public String operatorNumeric;
+ public String operatorAlphaLong;
}
public void
@@ -1047,6 +1049,7 @@ public class GSMPhone extends PhoneBase {
NetworkSelectMessage nsm = new NetworkSelectMessage();
nsm.message = response;
nsm.operatorNumeric = "";
+ nsm.operatorAlphaLong = "";
// get the message
Message msg = h.obtainMessage(EVENT_SET_NETWORK_AUTOMATIC_COMPLETE, nsm);
@@ -1064,6 +1067,7 @@ public class GSMPhone extends PhoneBase {
NetworkSelectMessage nsm = new NetworkSelectMessage();
nsm.message = response;
nsm.operatorNumeric = network.operatorNumeric;
+ nsm.operatorAlphaLong = network.operatorAlphaLong;
// get the message
Message msg = h.obtainMessage(EVENT_SET_NETWORK_MANUAL_COMPLETE, nsm);
@@ -1499,6 +1503,7 @@ public class GSMPhone extends PhoneBase {
SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(getContext());
SharedPreferences.Editor editor = sp.edit();
editor.putString(NETWORK_SELECTION_KEY, nsm.operatorNumeric);
+ editor.putString(NETWORK_SELECTION_NAME_KEY, nsm.operatorAlphaLong);
// commit and log the result.
if (! editor.commit()) {
diff --git a/telephony/java/com/android/internal/telephony/PhoneBase.java b/telephony/java/com/android/internal/telephony/PhoneBase.java
index 6e2b3f3..b279527 100644
--- a/telephony/java/com/android/internal/telephony/PhoneBase.java
+++ b/telephony/java/com/android/internal/telephony/PhoneBase.java
@@ -59,10 +59,13 @@ public abstract class PhoneBase implements Phone {
private static final String LOG_TAG = "PHONE";
private static final boolean LOCAL_DEBUG = true;
- // Key used to read and write the saved network selection value
+ // Key used to read and write the saved network selection numeric value
public static final String NETWORK_SELECTION_KEY = "network_selection_key";
+ // Key used to read and write the saved network selection operator name
+ public static final String NETWORK_SELECTION_NAME_KEY = "network_selection_name_key";
- // Key used to read/write "disable data connection on boot" pref (used for testing)
+
+ // Key used to read/write "disable data connection on boot" pref (used for testing)
public static final String DATA_DISABLED_ON_BOOT_KEY = "disabled_on_boot_key";
//***** Event Constants